.. currentmodule:: odooly

Introduction
============

This section gives the bare minimum to use Odooly as a :ref:`command line
tool <command-line>` or within an :ref:`interactive shell <interactive-mode>`.

Installation
------------

Download and install the `latest release
<https://pypi.org/project/Odooly>`__ from PyPI::

    pip install -U odooly


.. _interactive-mode:

.. include:: ../README.rst
   :start-after: _interactive-mode:

More details in the :doc:`tutorial` section.
